package wusthelper.web.api.v2.code;

import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * <h>响应码枚举</h>
 * <ul>
 *  <li>BASE_ 基本状态码:  10000-19999</li>
 *  <li>AUTH_ 用户身份验证C:  20000-29999</li>
 *  <li>JWC_  教务处:  30000-39999</li>
 *  <li>LIB_  图书馆:  40000-49999</li>
 *  <li>VOL_  工时:  50000-59999</li>
 *  <li>YJS_  研究生:  80000-89999</li>
 * </ul>
 * <p>状态码表示含义： <br>
 *    12345: 1号模块23号接口45型状态
 * </p>
 *
 * <p>
 *     <br>
 *     关于状态码统一: <br>
 *     由于安卓端表示成功状态码过于繁杂，这里对成功的状态码进行了统一： <br>
 *     所有成功状态： 10000 <br>
 *     所有因官方崩溃产生的失败，但读取本地数据成功的状态： 11000 <br>
 *     修改: 2021/3/12 田
 * </p>
 * <br><br>
 * <p>LingHang业务接口</p>
 *
 * @Author WSharkCoder
 * @Date 2021/1/15 21:40
 * @ClassName ResponseCode
 */
@AllArgsConstructor
@Getter
public enum V2ResponseCode {
    //基本状态码 START (1)
    /**
     * 成功
     */
    SUC(10000, "成功"),
    /**
     * 本地成功
     */
    LOCAL_SUC(11000, "本地成功"),

    /**
     * 操作频繁
     */
    LIMIT_REQUEST(99999, "操作频繁，请稍后再试"),
    /**
     * 失败
     */
    ERR(11111, "失败"),
    /**
     * 参数缺失或参数类型错误
     */
    BASE_PARAM_ERR(10001, "参数缺失或参数类型错误"),
    /**
     * 拒绝请求
     */
    REQUEST_DENIED(10002, "请求错误"),
    /**
     * 接口调用错误:请求方式出错或者参数缺失
     */
    REQUEST_CALLED_ERR(10003, "接口调用错误:请求出错，data中为错误信息，请检查并详细参照api文档使用该接口"),
    /**
     * 客户端连接中断
     */
    CLIENT_ABORT_ERR(10004, "连接中断"),
    //基本状态码 END

    //身份验证状态码 START (2)
    /**
     * 用户身份验证模块异常
     */
    AUTH_ERR(20001, "用户身份验证模块异常"),
    /**
     * 用户身份校验失败:请求缺失令牌TOKEN
     */
    AUTH_ERR_TOKEN_MISS(21001, "用户身份校验失败:请求缺失令牌TOKEN"),
    /**
     * 用户身份校验失败:TOKEN无效或过期
     */
    AUTH_ERR_TOKEN_INVALID(21002, "用户身份校验失败:TOKEN无效或过期"),
    /**
     * TOKEN解密成功
     */
    AUTH_DECODE_FOR_STUNUM_SUC(10000, "TOKEN解密成功"),
    /**
     * TOKEN解密失败
     */
    AUTH_DECODE_FOR_STUNUM_ERR(21101, "TOKEN解密失败"),
    //身份验证状态码 END


    //JWC模块状态码 START (3)
    /**
     * 教务处密码已修改,请重新登录!
     */
    JWC_PWD_NED_UPD(30001, "教务处密码已修改,请重新登录"),
    /**
     * 教务处登录成功
     */
    JWC_LOGIN_SUC(10000, "教务处登录成功"),
    /**
     * 教务登录失败:教务崩溃
     */
    JWC_LOGIN_ERR_JWC_ERR(30104, "登录失败:教务系统异常，请重试"),
    /**
     * 教务处登录失败:账号或密码错误
     */
    JWC_LOGIN_ERR_JWC_FIN_INFO_ERR(30101, "登陆失败:账号或密码错误"),
    /**
     * 教务处登录失败:需用户前往教务处修改默认密码
     */
    JWC_LOGIN_ERR_JWC_MOD_DEF_PWD(30102, "登录失败:请前往教务官网修改默认密码"),
    /**
     * 教务登录失败:教务崩溃|本地登录失败:本地账号或密码错误
     */
    JWC_LOGIN_ERR_JWC_ERR_INFO_ERR(30103, "登录失败:账号或密码错误，或教务异常，请重试"),
    /**
     * 教务处登录失败:重试次数过多
     */
    JWC_LOGIN_ERR_JWC_RETRY_TOO_MANY_TIMES_ERR(30101, "登录失败:密码重试次数已达三次，继续重试可能会导致暂时封禁，请等待约三分钟后重试，请确保账号和密码为“统一认证平台”的账号和密码，如忘记可前往官网进行密码找回"),
    /**
     * 教务处登录失败:重试次数过多被封禁
     */
    JWC_LOGIN_ERR_JWC_USER_WAS_BANNED_ERR(30101, "登录失败:密码总重试次数已达五次，已被暂时封禁，请等待约十分钟后重试，请确保账号和密码为“统一认证平台”的账号和密码，如忘记可前往官网进行密码找回"),
    /**
     * 教务登录失败:教务崩溃|本地登录成功
     */
    JWC_LOGIN_SUC_JWC_ERR_LOC_SUC(11000, "教务异常:缓存登录成功"),
    /**
     * 教务处获取用户信息成功
     */
    JWC_GETSTUINFO_SUC(10000, "教务处获取用户信息成功"),
    /**
     * 教务处获取用户信息失败:教务处崩溃|本地学生信息获取成功
     */
    JWC_GETSTUINFO_SUC_JWC_ERR_LOC_SUC(11000, "教务异常:缓存学生信息获取成功"),
    /**
     * 教务处获取用户信息失败，用户不存在
     */
    JWC_GETSTUINFO_ERR_NO_SUCH_STU(30201, "教务处获取用户信息失败:用户不存在"),
    /**
     * 教务处获取课表信息成功
     */
    JWC_GETCURRICULUM_SUC(10000, "教务处获取课表信息成功"),
    /**
     * 教务处获取课表信息失败:教务崩溃|本地课表信息获取成功
     */
    JWC_GETCURRICULUM_SUC_JWC_ERR_LOC_SUC(11000, "教务异常:缓存课表信息获取成功"),
    /**
     * 教务异常:获取课表失败
     */
    JWC_GETCURRICULUM_ERR_JWC_ERR(30301, "教务异常:获取课表失败"),
    /**
     * 教务公告列表获取成功
     */
    JWC_GETJWCANNLIST_SUC(10000, "教务公告列表获取成功"),
    /**
     * 教务公告内容获取成功
     */
    JWC_GETJWCANNCNT_SUC(10000, "教务公告内容获取成功"),
    /**
     * 教务处成绩获取成功
     */
    JWC_GETGRADE_SUC(10000, "教务处成绩获取成功"),
    /**
     * 教务处成绩获取失败:需用户前往教务处评教|本地成绩获取成功
     */
    JWC_GETGRADE_ERR_NEED_EVALUATE_TEACHING(30601, "教务处成绩获取失败:请前往教务官网评教"),
    /**
     * 教务处成绩获取失败:教务处崩溃|本地成绩获取成功
     */
    JWC_GETGRADE_ERR_JWC_ERR_LOC_SUC(11000, "教务异常:缓存成绩获取成功"),
    /**
     * 教务处学分明细获取成功
     */
    JWC_GETCREDIT_SUC(10000, "教务处学分明细获取成功"),
    /**
     * 教务处学分明细获取失败:教务处崩溃|本地学分明细获取成功
     */
    JWC_GETCREDIT_SUC_JWC_ERR_LOC_SUC(11000, "教务异常:缓存学分明细获取成功"),

    JWC_TRAINING_SCHEME_SUC(10000, "教务处培养方案获取成功"),
    JWC_TRAINING_SCHEME_ERR(30701, "教务异常，培养方案获取失败"),

    //JWC模块验证码 END


    //LIB状态码 START (4)
    /**
     * 图书馆密码已经修改，请重新登录!
     */
    LIB_PWD_NED_UPD(40001, "图书馆密码已经修改，请重新登录!"),
    /**
     * 图书馆登录已过期，请重新登录
     */
    LIB_LOGIN_EXPIRE(40002, "图书馆登录已过期，请重新登录"),
    /**
     * 图书馆登录成功
     */
    LIB_LOGIN_SUC(10000, "图书馆登录成功"),
    /**
     * 图书馆登录失败:账号或密码错误
     */
    LIB_LOGIN_ERR_LIB_FIN_INFO_ERR(40101, "登录失败:账号或密码错误"),
    /**
     * 图书馆登录失败:验证码错误
     */
    LIB_LOGIN_ERR_WRONG_AUTH_CODE(40103, "登录失败:验证码错误"),
    /**
     * 图书馆登录失败:登陆失败次数过多，请稍后重试
     */
    LIB_LOGIN_ERR_TOO_MUCH_TIME(40104, "登录失败:登陆失败次数过多，请稍后重试"),
    /**
     * 图书馆登录失败:图书馆崩溃|本地登录失败:账号或密码错误
     */
    LIB_LOGIN_ERR_LIB_ERR_INFO_ERR(40102, "登录失败:账号或密码错误"),
    /**
     * 图书馆登录失败:图书管崩溃|本地登录成功
     */
    LIB_LOGIN_ERR_LIB_ERR_LOC_SUC(11000, "图书管异常:缓存登录成功"),
    /**
     * 图书馆历史借阅记录获取成功
     */
    LIB_GETRENTHISTORY_SUC(10000, "图书馆历史借阅记录获取成功"),
    /**
     * 图书馆崩溃|本地图书馆借阅历史缓存获取成功
     */
    LIB_GETRENTHISTORY_SUC_LIB_ERR_LOC_SUC(11000, "图书馆异常:缓存图书馆借阅历史缓存获取成功"),
    /**
     * 图书馆当前借阅记录获取成功
     */
    LIB_GETCURRENTRENT_SUC(10000, "图书馆当前借阅记录获取成功"),
    /**
     * 图书馆崩溃|本地当前借阅获取成功
     */
    LIB_GETCURRENTRENT_SUC_LIB_ERR_LOC_SUC(11000, "图书馆异常:缓存当前借阅获取成功"),
    /**
     * 图书馆异常:缓存借阅记录获取成功
     */
    LIB_GETRENT_SUC_LIB_ERR_LOC_SUC(11000, "图书馆异常:缓存借阅记录获取成功"),
    /**
     * 借阅记录获取成功
     */
    LIB_GETRENT_SUC(10000, "借阅记录获取成功"),
    /**
     * 图书馆公告列表获取成功
     */
    LIB_GETLIBANNLIST_SUC(10000, "图书馆公告列表获取成功"),
    /**
     * 图书馆公告内容获取成功
     */
    LIB_GETLIBANNCNT_SUC(10000, "图书馆公告内容获取成功"),
    /**
     * 图书馆检索图书成功
     */
    LIB_SEARCH_SUC(10000, "图书馆检索图书成功"),
    /**
     * 图书馆检索图书异常
     */
    LIB_SEARCH_ERR(40601, "图书馆检索图书异常"),
    /**
     * 图书馆获取图书详情成功
     */
    LIB_GETBOOKDETAIL_SUC(10000, "图书馆获取图书详情成功"),
    /**
     * 图书馆获取图书详情异常
     */
    LIB_GETBOOKDETAIL_ERR(40701, "图书馆获取图书详情异常"),
    /**
     * 图书馆增添收藏成功
     */
    LIB_ADDCOLLECTION_SUC(10000, "图书馆增添收藏成功"),
    /**
     * 图书馆添加收藏异常
     */
    LIB_ADDCOLLECTION_ERR(40801, "图书馆添加收藏异常"),
    /**
     * 图书馆收藏列表查询成功
     */
    LIB_LISTCOLLECTION_SUC(10000, "图书馆收藏列表查询成功"),
    /**
     * 图书馆收藏删除成功
     */
    LIB_DELCOLLECTION_SUC(10000, "图书馆收藏删除成功"),
    /**
     * 图书馆获取验证码成功
     */
    LIB_GETYZM_SUC(11111, "图书馆获取验证码成功"),
    /**
     * 图书馆获取借阅历史和当前借阅成功
     */
    LIB_GETCRH_SUC(10101, "图书馆获取借阅历史和当前借阅成功"),

    //LIB状态码 END

    //YJS状态码 START ()

    /**
     * 研究生官网登录成功
     */
    YJS_LOGIN_SUC(10000, "研究生官网登录成功"),
    /**
     * 研究生官网登录失败:账号或密码错误
     */
    YJS_LOGIN_ERR_YJS_FIN_INFO_ERR(80002, "登录失败:账号或密码错误"),

    YJS_LOGIN_ERROR(11111, "登录失败，研究生官网异常，请稍后再试"),

    YJS_GETSTUINFO_SUC(10000, "研究生官网获取用户信息成功"),

    YJS_GETSTUINFO_ERR(11111, "研究生官网异常，获取用户信息失败，请稍后再试"),

    YJS_GETGRADE_SUC(10000, "研究生官网成绩获取成功"),

    YJS_GETGRADE_ERR(11111, "研究生官网异常，获取成绩失败，请稍后再试"),

    YJS_GETCOURSE_SUC(10000, "研究生官网课表获取成功"),

    YJS_GETCOURSE_ERR(11111, "研究生官网异常，刷新课表失败，请稍后再试"),

    YJS_GETTRAINPLAN_SUC(10000, "研究生官网培养管理获取成功"),

    YJS_GETTRAINPLAN_ERR(11111, "研究生官网异常，获取培养管理失败，请稍后再试"),

    YJS_PWD_NED_UPD(80001, "研究生官网密码已修改,请重新登录"),


    //YJS状态码 END

    //倒计时 START (5)
    /**
     * 倒计时:操作成功
     */
    COUNTDOWN_OPERATION_SUC(10000, "倒计时:操作成功"),
    //倒计时 END


    //消息中心 START (6)
    /**
     * 发送邮件成功
     */
    SEND_EMAIL_SUC(10000, "发送邮件成功"),
    /**
     * 无效的消息来源
     */
    MSG_ORIGIN_INVALID(60003, "无效的消息来源"),
    /**
     * 发送邮件失败
     */
    SEND_EMAIL_ERR(60001, "发送邮件失败"),
    /**
     * 发送邮件失败，收件邮箱不存在
     */
    SEND_EMAIL_ERR_INVALID_TAR_ERR(60002, "发送邮件失败，收件邮箱不存在或产生其他问题"),
    /**
     * 向飞书通知群发送消息成功
     */
    SEND_MSG_TO_FEISHU_SUC(10000, "向飞书通知群发送消息成功"),
    /**
     * 向飞书通知群发送消息失败
     */
    SEND_MSG_TO_FEISHU_ERR(60101, "向飞书通知群发送消息失败"),
    /**
     * 向安卓客户端发送消息成功
     */
    SEND_MSG_TO_ANDROID_SUC(10000, "向安卓客户端发送消息成功"),
    /**
     * 向安卓客户端发送消息失败
     */
    SEND_MSG_TO_ANDROID_ERR(60201, "向安卓客户端发送消息失败，用户可能不在线上，或是发生错误"),
    /**
     * 获取全部安卓端记录消息成功
     */
    ANDROID_MSG_GET_SUC(10000, "获取全部安卓端记录消息成功"),
    //消息中心 END


    //物理实验 START (7)
    /**
     * 登陆失败:账号或密码错误，或不在实验课不在本学期
     */
    WLSY_LOGIN_ERR_WLSY_FIN_INFO_ERR(70001, "登陆失败:账号或密码错误，或不在实验课不在本学期"),
    /**
     * 登陆失败:实验系统官网异常，请重试
     */
    WLSY_LOGIN_ERR_WLSY_ERR(70002, "登陆失败:实验系统官网异常，请重试"),
    /**
     * 实验系统异常:缓存登陆成功
     */
    WLSY_LOGIN_ERR_WLSY_ERR_LOC_SUC(11000, "实验系统异常:缓存登陆成功"),
    /**
     * 物理实验系统登陆成功
     */
    WLSY_LOGIN_SUC(10000, "物理实验系统登陆成功"),
    /**
     * 获取已选实验课失败:实验系统官网异常
     */
    WLSY_GETCOURSE_ERR_WLSY_ERR(70101, "获取已选实验课失败:实验系统官网异常"),
    /**
     * 获取已选实验课失败:登录过期
     */
    WLSY_GETCOURSE_ERR_LOGIN_EXPIRED(70102, "获取已选实验课失败:登录过期"),
    /**
     * 实验系统异常:缓存获取已选实验课成功
     */
    WLSY_GETCOURSE_ERR_WLSY_ERR_LOC_SUC(11000, "实验系统异常:缓存获取已选实验课成功"),
    /**
     * 获取已选实验课成功
     */
    WLSY_GETCOURSE_SUC(10000, "获取已选实验课成功"),
    //物理实验 END


    //教室查询 START (8)
    /**
     * 查询空教室成功
     */
    CLSR_SEARCH_EMPTY_CLASSROOM_SUC(10000, "查询空教室成功"),
    /**
     * 查询学院列表成功
     */
    CLSR_GET_COLLEGE_LIST_SUC(10000, "查询学院列表成功"),
    /**
     * 查询课名列表成功
     */
    CLSR_GET_COURSE_NAME_LIST_SUC(10000, "查询课名列表成功"),
    /**
     * 查询课程详情成功
     */
    CLSR_GET_COURSE_DETAIL_LIST_SUC(10000, "查询课程详情成功"),
    /**
     * 查询结果为空
     */
    CLSR_RESULT_EMPTY(80001, "查询结果为空"),
    /**
     * 已是最后一页
     */
    CLSR_NO_MORE_PAGE(80002, "已是最后一页"),
    //教室查询 END (8)


    //助手信息查询 BEGIN (9)
    /**
     * 获取用户详情信息成功
     */
    GET_USER_INFO_SUC(10000, "获取用户详情信息成功"),
    /**
     * 获取用户操作记录成功
     */
    GET_USER_OPE_RECORD_SUC(10000, "获取用户操作记录成功"),
    /**
     * 获取学号列表成功
     */
    GET_STU_NUM_LIST_SUC(10000, "获取学号列表成功"),
    /**
     * 获取用户信息失败，用户不存在
     */
    GET_USER_INFO_ERR_USER_NOT_EXIST(90001, "获取用户信息失败，用户不存在"),
    /**
     * 获取用户操作记录失败，用户不存在
     */
    GET_USER_OPE_RECORD_ERR_USER_NOT_EXIST(90101, "获取用户操作记录失败，用户不存在"),
    /**
     * 目标日志不存在或为空
     */
    LOG_EMPTY_OR_NOT_EXIST(90201, "目标日志不存在或为空"),
    /**
     * 获取日志信息成功
     */
    GET_LOG_INFO_SUC(10000, "获取日志信息成功"),
    /**
     * 获取时段请求信息成功
     */
    GET_TIME_REPORT_SUC(10000, "获取时段请求信息成功"),
    //助手信息查询 END   (9)
    ;

    private final int code;
    private final String msg;
}
