package wusthelper.web.api.v2.dto.response;

import cn.wustlinghang.mywust.data.global.Course;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class CourseResponse {
    /**
     * 课程名称
     */
    private String className;

    /**
     * 教学班
     */
    private String teachClass;

    /**
     * 教师
     */
    private String teacher;

    /**
     * 开始周次
     */
    private Integer startWeek;

    /**
     * 结束周
     */
    private Integer endWeek;

    /**
     * 节数
     */
    private Integer section;

    /**
     * 星期
     */
    private Integer weekDay;

    /**
     * 教室
     */
    private String classroom;

    public static CourseResponse from(Course course) {
        CourseResponse courseResponse = new CourseResponse();
        courseResponse.setClassName(course.getName());
        courseResponse.setTeachClass(course.getTeachClass());
        courseResponse.setTeacher(course.getTeacher());
        courseResponse.setStartWeek(course.getStartWeek());
        courseResponse.setEndWeek(course.getEndWeek());
        courseResponse.setSection((course.getStartSection() + 1) / 2);
        courseResponse.setWeekDay(course.getWeekDay());
        courseResponse.setClassroom(course.getClassroom().getRoom());

        return courseResponse;
    }

    /**
     * 切课，将连着的几节课切开来
     *
     * @param courses mywust类型的CourseList
     * @return List<CourseResponse>
     */
    public static List<CourseResponse> convertCourseList(Collection<Course> courses) {
        List<CourseResponse> courseResponses = new ArrayList<>(courses.size() * 2);

        CourseResponse.CourseResponseBuilder builder = CourseResponse.builder();
        for (Course course : courses) {
            builder.className(course.getName());
            builder.teachClass(course.getTeachClass());
            builder.classroom(course.getClassroom().getRoom());
            builder.startWeek(course.getStartWeek());
            builder.endWeek(course.getEndWeek());
            builder.weekDay(course.getWeekDay());
            builder.teacher(course.getTeacher());

            int startSection = course.getStartSection();
            int endSection = course.getEndSection();

            int courseSize = endSection - startSection + 1;

            // 课程大小大于2的将课程按两节两节分割，只有一节的按两节处理
            if (courseSize > 2) {
                for (int i = 0; i < courseSize / 2; i++) {
                    int splitStartSection = startSection + i * 2;
                    int section = splitStartSection - (splitStartSection / 2);
                    builder.section(section);

                    courseResponses.add(builder.build());
                }
            } else {
                builder.section(startSection - (startSection / 2));
                courseResponses.add(builder.build());
            }
        }

        return courseResponses;
    }
}
