package wusthelper.web.api.v2.module.graduate;

import cn.wustlinghang.mywust.data.global.Course;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import wusthelper.web.annotation.RequireToken;
import wusthelper.web.api.v2.TokenTool;
import wusthelper.web.api.v2.code.V2ResponseCode;
import wusthelper.web.api.v2.dto.response.CourseResponse;
import wusthelper.web.api.v2.dto.response.graduate.GraduateScoreResponse;
import wusthelper.web.api.v2.dto.response.graduate.GraduateStudentInfoResponse;
import wusthelper.web.response.Response;
import wusthelper.web.service.campus.graduate.GraduateCourseTableService;
import wusthelper.web.service.campus.graduate.GraduateScoreService;
import wusthelper.web.service.campus.graduate.GraduateStudentInfoService;
import wusthelper.web.service.campus.graduate.GraduateTrainingPlanService;

import java.util.ArrayList;
import java.util.Collection;
import java.util.LinkedHashSet;
import java.util.List;

@RequireToken
@RestController
@RequestMapping("/v2/yjs")
public class GraduateController {

    private final GraduateStudentInfoService studentInfoService;
    private final GraduateCourseTableService courseTableService;
    private final GraduateScoreService scoreService;
    private final GraduateTrainingPlanService trainingPlanService;

    public GraduateController(GraduateStudentInfoService studentInfoService,
                              GraduateCourseTableService courseTableService,
                              GraduateScoreService scoreService,
                              GraduateTrainingPlanService trainingPlanService) {

        this.studentInfoService = studentInfoService;
        this.courseTableService = courseTableService;
        this.scoreService = scoreService;
        this.trainingPlanService = trainingPlanService;
    }

    @RequestMapping("/get-student-info")
    public Response<GraduateStudentInfoResponse> getStudentInfo(@RequestHeader("Token") String token) {
        var user = TokenTool.getStudentNumber(token);
        var studentInfo = studentInfoService.getStudentInfo(user);
        var response = GraduateStudentInfoResponse.from(studentInfo);

        return Response.success(V2ResponseCode.YJS_GETSTUINFO_SUC.getCode(), response);
    }

    @RequestMapping("/get-course")
    public Response<List<CourseResponse>> getCourses(@RequestHeader("Token") String token) {
        var user = TokenTool.getStudentNumber(token);
        var courses = courseTableService.getCourseTable(user);
        LinkedHashSet<Course> filteredCourse = new LinkedHashSet<>(courses);
        var resultList = CourseResponse.convertCourseList(filteredCourse);

        return Response.success(V2ResponseCode.YJS_GETCOURSE_SUC.getCode(), resultList);
    }

    @RequestMapping("/get-grade")
    public Response<List<GraduateScoreResponse>> getScore(@RequestHeader("Token") String token) {
        var user = TokenTool.getStudentNumber(token);
        var scores = scoreService.getScore(user);
        var resultList = new ArrayList<GraduateScoreResponse>(scores.size());
        for (var score : scores) {
            resultList.add(GraduateScoreResponse.from(score));
        }

        return Response.success(V2ResponseCode.YJS_GETGRADE_SUC.getCode(), resultList);
    }

    @RequestMapping("/get-scheme")
    public Response<String> getTrainingPlan(@RequestHeader("Token") String token) {
        var user = TokenTool.getStudentNumber(token);
        var page = trainingPlanService.getTrainingPlan(user);

        return Response.success(V2ResponseCode.YJS_GETTRAINPLAN_SUC.getCode(), page);
    }
}
