package wusthelper.web.api.v2.module.library;

import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import wusthelper.code.ServiceCode;
import wusthelper.web.api.v2.code.V2ResponseCode;
import wusthelper.web.api.v2.dto.response.library.BookDetailResponse;
import wusthelper.web.api.v2.dto.response.library.BookSearchResponseItem;
import wusthelper.web.response.Response;
import wusthelper.web.service.campus.library.LibraryPublicService;

import java.util.*;
import java.util.regex.Pattern;

@RestController
@RequestMapping("/v2/lib")
public class LibraryPublicController {
    private final LibraryPublicService service;

    public LibraryPublicController(LibraryPublicService service) {
        this.service = service;
    }

    private static final Pattern BOOK_URL_PATTERN = Pattern.compile("https://libsys.wust.edu.cn/meta-local/opac/bibs/(.*?)/infos");

    @RequestMapping(path = "/get-book-detail")
    public Response<BookDetailResponse> getBookDetail(@RequestParam(value = "url") String url) {
        var urlMatcher = BOOK_URL_PATTERN.matcher(url);
        if (!urlMatcher.find()) {
            return Response.error(ServiceCode.ParamWrong);
        }
        var id = urlMatcher.group(1);
        var detail = service.getBookDetail(id);

        var responseData = BookDetailResponse.from(detail);

        var holdingInfoList = service.getBookHolding(id);
        List<BookDetailResponse.BookHoldingInfo> bookHoldingInfoList = new ArrayList<>(holdingInfoList.size());
        for (var holdingInfo : holdingInfoList) {
            var bookHoldingInfo = BookDetailResponse.BookHoldingInfo.from(holdingInfo);
            bookHoldingInfoList.add(bookHoldingInfo);
        }
        responseData.setList(bookHoldingInfoList);

        return Response.success(V2ResponseCode.LIB_GETBOOKDETAIL_SUC.getCode(), responseData);
    }

    @RequestMapping(path = "/search")
    public Response<List<BookSearchResponseItem>> search(
            @RequestParam(value = "keyWord") String keyword,
            @RequestParam(value = "pageNum", required = false, defaultValue = "1") int page,
            @RequestParam(value = "pageSize", required = false, defaultValue = "20") int pageSize
    ) {
        var upstreamResultList = service.searchBooks(keyword, page, pageSize).getData();
        var responseData = new ArrayList<BookSearchResponseItem>(upstreamResultList.size());
        var isbnList = new ArrayList<String>(upstreamResultList.size());
        for (var result : upstreamResultList) {
            var item = BookSearchResponseItem.from(result);
            item.setAllNum("1");
            item.setRemainNum("1");
            responseData.add(item);
            isbnList.add(result.getIsbn());
        }

        var coverUrls = service.getBookCoverImageBatch(isbnList);
        for (var item : responseData) {
            item.setImgUrl(coverUrls.get(item.getIsbn()).get(0));
        }

        return Response.success(V2ResponseCode.LIB_SEARCH_SUC.getCode(), responseData);
    }
}
