package wusthelper.web.service.campus.library;

import cn.wustlinghang.mywust.data.library.PagingResult;
import cn.wustlinghang.mywust.data.library.origin.BaseLoanBook;
import cn.wustlinghang.mywust.data.library.origin.CurrentLoanBook;
import cn.wustlinghang.mywust.data.library.origin.HistoryLoanBook;
import org.springframework.stereotype.Service;
import wusthelper.code.ServiceCode;
import wusthelper.web.data.entity.CookieType;
import wusthelper.web.exception.ServiceException;
import wusthelper.web.rpc.http.library.LibraryCurrentLoanRemote;
import wusthelper.web.rpc.http.library.LibraryLoanHistoryRemote;
import wusthelper.web.rpc.http.library.LibraryOverdueSoonRemote;
import wusthelper.web.service.cookie.CookieManager;

import java.util.List;

@Service
public class LibraryPersonalService {
    private final CookieManager cookieManager;

    private final LibraryCurrentLoanRemote currentLoanRemote;
    private final LibraryLoanHistoryRemote loanHistoryRemote;
    private final LibraryOverdueSoonRemote overdueSoonRemote;

    public LibraryPersonalService(CookieManager cookieManager,
                                  LibraryCurrentLoanRemote currentLoanRemote,
                                  LibraryLoanHistoryRemote loanHistoryRemote,
                                  LibraryOverdueSoonRemote overdueSoonRemote) {

        this.cookieManager = cookieManager;

        this.currentLoanRemote = currentLoanRemote;
        this.loanHistoryRemote = loanHistoryRemote;
        this.overdueSoonRemote = overdueSoonRemote;
    }

    public PagingResult<List<CurrentLoanBook>> getCurrentLoan(String user, int page, int pageSize) {
        String cookie = cookieManager.getCookie(user, CookieType.Library);
        var rpcResp = currentLoanRemote.get(cookie, page, pageSize);
        if (rpcResp.code() != ServiceCode.Ok) {
            ServiceException.error(rpcResp.code());
        }

        // todo 异步存用户课表，异常判断等等
        return rpcResp.data();
    }

    public PagingResult<List<HistoryLoanBook>> getLoanHistory(String user, int page, int pageSize) {
        String cookie = cookieManager.getCookie(user, CookieType.Library);
        var rpcResp = loanHistoryRemote.get(cookie, page, pageSize);
        if (rpcResp.code() != ServiceCode.Ok) {
            ServiceException.error(rpcResp.code());
        }

        // todo 异步存用户课表，异常判断等等
        return rpcResp.data();
    }

    public PagingResult<List<BaseLoanBook>> getOverdueSoon(String user, int page, int pageSize) {
        String cookie = cookieManager.getCookie(user, CookieType.Library);
        var rpcResp = overdueSoonRemote.get(cookie, page, pageSize);
        if (rpcResp.code() != ServiceCode.Ok) {
            ServiceException.error(rpcResp.code());
        }

        // todo 异步存用户课表，异常判断等等
        return rpcResp.data();
    }
}
